pub struct WorkerBatch {
pub state_version: CommitVersion,
pub instructions: Vec<FlowInstruction>,
}Expand description
A batch of instructions for a single worker.
Contains instructions for multiple flows, all of which are assigned to the same worker via hash partitioning (flow_id % num_workers).
Fields
state_version: CommitVersionThe version to use for reading flow state. This is constant for the entire CDC batch being processed.
instructions: Vec<FlowInstruction>Instructions for each flow assigned to this worker. Each flow appears at most once in this list.
Implementations
Sourceimpl WorkerBatch
impl WorkerBatch
Sourcepub fn new(state_version: CommitVersion) -> Self
pub fn new(state_version: CommitVersion) -> Self
Create a new empty worker batch.
Sourcepub fn add_instruction(&mut self, instruction: FlowInstruction)
pub fn add_instruction(&mut self, instruction: FlowInstruction)
Add an instruction to this batch.