Module evolution

Module evolution 

Schema evolution and resolution utilities.

SchemaResolver handles reading data written with one schema using a different (but compatible) target schema.

Structs

SchemaResolver
Resolves differences between source and target schemas.

Enums

FieldMapping
Describes how to map a source field to a target field during schema evolution.