pub struct SchemaResolver { /* private fields */ }Expand description
Resolves differences between source and target schemas.
Used when reading data that was written with an older schema version using a newer schema, or vice versa.
Implementations
Sourceimpl SchemaResolver
impl SchemaResolver
Sourcepub fn new(source: Schema, target: Schema) -> Option<Self>
pub fn new(source: Schema, target: Schema) -> Option<Self>
Create a resolver to read data from source schema as target schema.
Returns None if the schemas are incompatible (e.g., type mismatch on same-named field without valid widening path).
Sourcepub fn mappings(&self) -> &[FieldMapping]
pub fn mappings(&self) -> &[FieldMapping]
Get the field mappings
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Check if this is an identity mapping (source == target)