Module evolution

Module evolution 

RowShape evolution and resolution utilities.

ShapeResolver handles reading data written with one shape using a different (but compatible) target shape.

Structs

ShapeResolver
Resolves differences between source and target shapes.

Enums

FieldMapping
Describes how to map a source field to a target field during shape evolution.