pub struct ShapeResolver { /* private fields */ }Expand description
Resolves differences between source and target shapes.
Used when reading data that was written with an older shape version using a newer shape, or vice versa.
Implementations
Sourceimpl ShapeResolver
impl ShapeResolver
Sourcepub fn new(source: RowShape, target: RowShape) -> Option<Self>
pub fn new(source: RowShape, target: RowShape) -> Option<Self>
Create a resolver to read data from source shape as target shape.
Returns None if the shapes are incompatible (e.g., type mismatch on same-named field without valid widening path).
Sourcepub fn mappings(&self) -> &[FieldMapping]
pub fn mappings(&self) -> &[FieldMapping]
Get the field mappings
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Check if this is an identity mapping (source == target)