#[repr(transparent)]pub struct RowShapeFingerprint(pub Hash64);Expand description
A fingerprint that uniquely identifies a shape layout.
This is an 8-byte hash stored in the header of every encoded row, allowing the shape to be identified without external metadata.
Tuple Fields
0: Hash64Implementations
Sourceimpl RowShapeFingerprint
impl RowShapeFingerprint
Sourcepub const fn to_le_bytes(&self) -> [u8; 8]
pub const fn to_le_bytes(&self) -> [u8; 8]
Convert to little-endian bytes.
Sourcepub const fn from_le_bytes(bytes: [u8; 8]) -> Self
pub const fn from_le_bytes(bytes: [u8; 8]) -> Self
Create from little-endian bytes.