pub struct RowShapeField {
pub name: String,
pub constraint: TypeConstraint,
pub offset: u32,
pub size: u32,
pub align: u8,
}Expand description
A field within a shape
Fields
name: StringField name
constraint: TypeConstraintField type constraint (includes base type and optional constraints like MaxBytes)
offset: u32Byte offset within the encoded row
size: u32Size in bytes
align: u8Alignment requirement
Implementations
Sourceimpl RowShapeField
impl RowShapeField
Sourcepub fn new(name: impl Into<String>, constraint: TypeConstraint) -> Self
pub fn new(name: impl Into<String>, constraint: TypeConstraint) -> Self
Create a new shape field with a type constraint. Offset, size, and alignment are computed when added to a RowShape.
Sourcepub fn unconstrained(name: impl Into<String>, field_type: Type) -> Self
pub fn unconstrained(name: impl Into<String>, field_type: Type) -> Self
Create a new shape field with an unconstrained type. Convenience method for the common case of no constraints.