Module flow

Module flow 

Structs

Flow
FlowEdge
Catalog definition for a flow edge
FlowEdgeId
FlowId
FlowNode
Catalog definition for a flow node The node type and its data are stored as a type discriminator and serialized blob
FlowNodeId

Enums

FlowStatus