pub struct FlowNode {
pub id: FlowNodeId,
pub flow: FlowId,
pub node_type: u8,
pub data: Blob,
}Expand description
Catalog definition for a flow node The node type and its data are stored as a type discriminator and serialized blob
Fields
id: FlowNodeIdflow: FlowIdnode_type: u8data: BlobTrait Implementations
impl StructuralPartialEq for FlowNode