Module migration

Module migration 

Structs

Migration
A migration definition stored in the catalog.
MigrationEvent
An audit trail entry for a migration apply or rollback. The CommitVersion is NOT a field - it’s the MVCC version key.

Enums

MigrationAction
The type of migration action recorded in the audit trail.

Functions

migration_hash
Compute the content hash for a migration body and optional rollback body.