PrimitiveId

Enum PrimitiveId 

pub enum PrimitiveId {
    Table(TableId),
    View(ViewId),
    Flow(FlowId),
    TableVirtual(VTableId),
    RingBuffer(RingBufferId),
    Dictionary(DictionaryId),
}
PrimitiveId represents identifiers for catalog primitives that use u64-based IDs.

Variants



Table(TableId)



View(ViewId)



Flow(FlowId)



TableVirtual(VTableId)



RingBuffer(RingBufferId)



Dictionary(DictionaryId)

Implementations

Source

impl PrimitiveId

pub fn table(id: impl Into<TableId>) -> Self

pub fn view(id: impl Into<ViewId>) -> Self

pub fn flow(id: impl Into<FlowId>) -> Self

pub fn vtable(id: impl Into<VTableId>) -> Self

pub fn ringbuffer(id: impl Into<RingBufferId>) -> Self

pub fn dictionary(id: impl Into<DictionaryId>) -> Self

pub fn to_u64(self) -> u64

Get the inner u64 value from the ID variant.

Source

impl PrimitiveId

pub fn to_type_u8(&self) -> u8

Returns the type discriminant as a u8 value

pub fn as_u64(&self) -> u64

Returns the raw u64 value regardless of the primitive type

pub fn next(&self) -> PrimitiveId

Creates a next primitive id for range operations (numerically next)

pub fn prev(&self) -> PrimitiveId

Creates a previous primitive id for range operations (numerically previous) In descending order encoding, this gives us the next value in sort order Uses wrapping_sub to handle ID 0 correctly (wraps to u64::MAX)

pub fn to_table_id(self) -> Result<TableId>

pub fn to_view_id(self) -> Result<ViewId>

pub fn to_flow_id(self) -> Result<FlowId>

pub fn to_vtable_id(self) -> Result<VTableId>

pub fn to_ringbuffer_id(self) -> Result<RingBufferId>

pub fn to_dictionary_id(self) -> Result<DictionaryId>