pub enum SchemaId {
Table(TableId),
View(ViewId),
TableVirtual(VTableId),
RingBuffer(RingBufferId),
Dictionary(DictionaryId),
Series(SeriesId),
}Expand description
SchemaId represents identifiers for catalog primitives that use u64-based IDs.
Variants
Table(TableId)
View(ViewId)
TableVirtual(VTableId)
RingBuffer(RingBufferId)
Dictionary(DictionaryId)
Series(SeriesId)
Implementations
Sourceimpl SchemaId
impl SchemaId
pub fn table(id: impl Into<TableId>) -> Self
pub fn view(id: impl Into<ViewId>) -> Self
pub fn vtable(id: impl Into<VTableId>) -> Self
pub fn ringbuffer(id: impl Into<RingBufferId>) -> Self
pub fn dictionary(id: impl Into<DictionaryId>) -> Self
pub fn series(id: impl Into<SeriesId>) -> Self
Sourceimpl SchemaId
impl SchemaId
Sourcepub fn to_type_u8(&self) -> u8
pub fn to_type_u8(&self) -> u8
Returns the type discriminant as a u8 value
Sourcepub fn next(&self) -> SchemaId
pub fn next(&self) -> SchemaId
Creates a next object id for range operations (numerically next)
Sourcepub fn prev(&self) -> SchemaId
pub fn prev(&self) -> SchemaId
Creates a previous object id for range operations (numerically previous) In descending order encoding, this gives us the next value in sort order Uses wrapping_sub to handle ID 0 correctly (wraps to u64::MAX)
pub fn to_table_id(self) -> Result<TableId>
pub fn to_view_id(self) -> Result<ViewId>
pub fn to_vtable_id(self) -> Result<VTableId>
pub fn to_ringbuffer_id(self) -> Result<RingBufferId>
pub fn to_dictionary_id(self) -> Result<DictionaryId>
pub fn to_series_id(self) -> Result<SeriesId>