Module subscription

Module subscription 

Structs

SubscriptionColumnDef
A column definition for a subscription. Simpler than regular ColumnDef - only has id, name, and type.
SubscriptionDef

Constants

IMPLICIT_COLUMN_OP
Implicit column names for subscriptions

Functions

subscription_flow_name
Returns the flow name for a subscription using the deterministic naming convention. Subscription flows are always created in the system namespace.
subscription_flow_namespace
Returns the namespace ID where subscription flows are created (system namespace).