pub enum ResolvedShape {
Table(ResolvedTable),
TableVirtual(ResolvedTableVirtual),
View(ResolvedView),
DeferredView(ResolvedDeferredView),
TransactionalView(ResolvedTransactionalView),
RingBuffer(ResolvedRingBuffer),
Dictionary(ResolvedDictionary),
Series(ResolvedSeries),
}Expand description
Unified enum for any resolved shape type
Variants
Table(ResolvedTable)
TableVirtual(ResolvedTableVirtual)
View(ResolvedView)
DeferredView(ResolvedDeferredView)
TransactionalView(ResolvedTransactionalView)
RingBuffer(ResolvedRingBuffer)
Dictionary(ResolvedDictionary)
Series(ResolvedSeries)
Implementations
Sourceimpl ResolvedShape
impl ResolvedShape
Sourcepub fn identifier(&self) -> &Fragment
pub fn identifier(&self) -> &Fragment
Get the identifier fragment
Sourcepub fn namespace(&self) -> Option<&ResolvedNamespace>
pub fn namespace(&self) -> Option<&ResolvedNamespace>
Get the namespace if this shape has one
Sourcepub fn supports_indexes(&self) -> bool
pub fn supports_indexes(&self) -> bool
Check if this shape supports indexes
Sourcepub fn supports_mutations(&self) -> bool
pub fn supports_mutations(&self) -> bool
Check if this shape supports mutations
Sourcepub fn find_column(&self, name: &str) -> Option<&Column>
pub fn find_column(&self, name: &str) -> Option<&Column>
Find a column by name
Sourcepub fn fully_qualified_name(&self) -> Option<String>
pub fn fully_qualified_name(&self) -> Option<String>
Get fully qualified name if available
Sourcepub fn as_table(&self) -> Option<&ResolvedTable>
pub fn as_table(&self) -> Option<&ResolvedTable>
Convert to a table if this is a table shape
Sourcepub fn as_view(&self) -> Option<&ResolvedView>
pub fn as_view(&self) -> Option<&ResolvedView>
Convert to a view if this is a view shape
Sourcepub fn as_ringbuffer(&self) -> Option<&ResolvedRingBuffer>
pub fn as_ringbuffer(&self) -> Option<&ResolvedRingBuffer>
Convert to a ring buffer if this is a ring buffer shape
Sourcepub fn as_dictionary(&self) -> Option<&ResolvedDictionary>
pub fn as_dictionary(&self) -> Option<&ResolvedDictionary>
Convert to a dictionary if this is a dictionary shape
Sourcepub fn as_series(&self) -> Option<&ResolvedSeries>
pub fn as_series(&self) -> Option<&ResolvedSeries>
Convert to a series if this is a series shape