pub struct RowKeyRange {
pub primitive: PrimitiveId,
}Fields
primitive: PrimitiveIdImplementations
Sourceimpl RowKeyRange
impl RowKeyRange
Sourcepub fn scan_range(
primitive: PrimitiveId,
last_key: Option<&EncodedKey>,
) -> EncodedKeyRange
pub fn scan_range( primitive: PrimitiveId, last_key: Option<&EncodedKey>, ) -> EncodedKeyRange
Create a range for scanning rows from a primitive
If last_key is provided, creates a range that continues from after that key.
Otherwise, creates a range that includes all rows for the primitive.
The caller is responsible for limiting the number of results returned.