Module shape

Module shape 

Structs

RowShapeFieldKey
Key for storing individual shape fields Keyed by (shape_fingerprint, field_index) for ordered retrieval
RowShapeKey
Key for storing a shape definition by its fingerprint