pub struct SubscriptionRowKeyRange {
pub subscription: SubscriptionId,
}Fields
subscription: SubscriptionIdImplementations
Sourceimpl SubscriptionRowKeyRange
impl SubscriptionRowKeyRange
Sourcepub fn scan_range(
subscription: SubscriptionId,
last_key: Option<&EncodedKey>,
) -> EncodedKeyRange
pub fn scan_range( subscription: SubscriptionId, last_key: Option<&EncodedKey>, ) -> EncodedKeyRange
Create a range for scanning rows from a subscription
If last_key is provided, creates a range that continues from after that key.
Otherwise, creates a range that includes all rows for the subscription.
The caller is responsible for limiting the number of results returned.