pub struct VariantHandlerKey {
pub namespace: NamespaceId,
pub sumtype: SumTypeId,
pub variant_tag: u8,
pub handler: HandlerId,
}Expand description
Key for looking up handlers by the variant they handle. Supports range scans for DISPATCH to find all handlers for a given (namespace, sumtype, variant_tag).
Fields
namespace: NamespaceIdsumtype: SumTypeIdvariant_tag: u8handler: HandlerIdImplementations
Sourceimpl VariantHandlerKey
impl VariantHandlerKey
pub fn new( namespace: NamespaceId, sumtype: SumTypeId, variant_tag: u8, handler: HandlerId, ) -> Self
pub fn encoded( namespace: impl Into<NamespaceId>, sumtype: impl Into<SumTypeId>, variant_tag: u8, handler: impl Into<HandlerId>, ) -> EncodedKey
Sourcepub fn variant_scan(
namespace: NamespaceId,
sumtype: SumTypeId,
variant_tag: u8,
) -> EncodedKeyRange
pub fn variant_scan( namespace: NamespaceId, sumtype: SumTypeId, variant_tag: u8, ) -> EncodedKeyRange
Range scan for all handlers of a specific variant.