pub struct PooledGuard<T: Releasable> { /* private fields */ }Expand description
A guard that automatically returns a container to its pool when dropped
This implements the RAII pattern for container pooling - when the guard goes out of scope, it automatically releases the contained value back to the pool for reuse.
Implementations
Sourceimpl<T: Releasable> PooledGuard<T>
impl<T: Releasable> PooledGuard<T>
Sourceimpl PooledGuard<Utf8Container>
impl PooledGuard<Utf8Container>
Sourcepub fn new_string(pools: Pools, capacity: usize) -> Self
pub fn new_string(pools: Pools, capacity: usize) -> Self
Create a new pooled StringContainer with the specified capacity
Sourceimpl PooledGuard<RowNumberContainer>
impl PooledGuard<RowNumberContainer>
Sourcepub fn new_row_number(pools: Pools, capacity: usize) -> Self
pub fn new_row_number(pools: Pools, capacity: usize) -> Self
Create a new pooled RowNumberContainer with the specified capacity
Sourceimpl PooledGuard<NumberContainer<i32>>
impl PooledGuard<NumberContainer<i32>>
Sourceimpl PooledGuard<NumberContainer<i64>>
impl PooledGuard<NumberContainer<i64>>
Sourceimpl PooledGuard<NumberContainer<f32>>
impl PooledGuard<NumberContainer<f32>>
Sourceimpl PooledGuard<NumberContainer<f64>>
impl PooledGuard<NumberContainer<f64>>
Sourceimpl PooledGuard<NumberContainer<i8>>
impl PooledGuard<NumberContainer<i8>>
Sourceimpl PooledGuard<NumberContainer<i16>>
impl PooledGuard<NumberContainer<i16>>
Sourceimpl PooledGuard<NumberContainer<u8>>
impl PooledGuard<NumberContainer<u8>>
Sourceimpl PooledGuard<NumberContainer<u16>>
impl PooledGuard<NumberContainer<u16>>
Sourceimpl PooledGuard<NumberContainer<u32>>
impl PooledGuard<NumberContainer<u32>>
Sourceimpl PooledGuard<NumberContainer<u64>>
impl PooledGuard<NumberContainer<u64>>
Sourceimpl PooledGuard<TemporalContainer<DateTime>>
impl PooledGuard<TemporalContainer<DateTime>>
Sourcepub fn new_datetime(pools: Pools, capacity: usize) -> Self
pub fn new_datetime(pools: Pools, capacity: usize) -> Self
Create a new pooled TemporalContainer
Sourceimpl PooledGuard<TemporalContainer<Duration>>
impl PooledGuard<TemporalContainer<Duration>>
Sourcepub fn new_duration(pools: Pools, capacity: usize) -> Self
pub fn new_duration(pools: Pools, capacity: usize) -> Self
Create a new pooled TemporalContainer
Sourceimpl PooledGuard<UuidContainer<Uuid4>>
impl PooledGuard<UuidContainer<Uuid4>>
Sourceimpl PooledGuard<UuidContainer<Uuid7>>
impl PooledGuard<UuidContainer<Uuid7>>