Schema evolution and resolution utilities.
SchemaResolver handles reading data written with one schema using a different (but compatible) target schema.
Structs
- Schema
Resolver - Resolves differences between source and target schemas.
Enums
- Field
Mapping - Describes how to map a source field to a target field during schema evolution.