Module shape

Module shape 

Modules

consolidate
evolution
fingerprint

Structs

Inner
Inner data for a shape describing the structure of encoded row data.
RowShape
A shape describing the structure of encoded row data.
RowShapeField
A field within a shape

Constants

SHAPE_HEADER_SIZE
Size of shape header (fingerprint) in bytes