Modules
Structs
- Inner
- Inner data for a shape describing the structure of encoded row data.
- RowShape
- A shape describing the structure of encoded row data.
- RowShape
Field - A field within a shape
Constants
- SHAPE_
HEADER_ SIZE - Size of shape header (fingerprint) in bytes