RowShape evolution and resolution utilities.
ShapeResolver handles reading data written with one shape using a different (but compatible) target shape.
Structs
- Shape
Resolver - Resolves differences between source and target shapes.
Enums
- Field
Mapping - Describes how to map a source field to a target field during shape evolution.