Module flow
reifydb_
core
0.4.12
Module flow
Module Items
Structs
Enums
In reifydb_
core::
interface::
catalog
reifydb_core
::
interface
::
catalog
Module
flow
Structs

Flow
Flow
Edge
Catalog definition for a flow edge
Flow
Edge
Id
FlowId
Flow
Node
Catalog definition for a flow node The node type and its data are stored as a type discriminator and serialized blob
Flow
Node
Id
Enums

Flow
Status