pub enum Procedure {
Rql {
id: ProcedureId,
namespace: NamespaceId,
name: String,
params: Vec<ProcedureParam>,
return_type: Option<TypeConstraint>,
body: String,
trigger: RqlTrigger,
},
Test {
id: ProcedureId,
namespace: NamespaceId,
name: String,
params: Vec<ProcedureParam>,
return_type: Option<TypeConstraint>,
body: String,
},
Native {
id: ProcedureId,
namespace: NamespaceId,
name: String,
params: Vec<ProcedureParam>,
return_type: Option<TypeConstraint>,
native_name: String,
},
Ffi {
id: ProcedureId,
namespace: NamespaceId,
name: String,
params: Vec<ProcedureParam>,
return_type: Option<TypeConstraint>,
native_name: String,
library_path: PathBuf,
entry_symbol: String,
},
Wasm {
id: ProcedureId,
namespace: NamespaceId,
name: String,
params: Vec<ProcedureParam>,
return_type: Option<TypeConstraint>,
native_name: String,
module_id: WasmModuleId,
},
}Variants
Rql
User-defined RQL procedure. Persisted; transactional; addable/droppable via DDL.
Fields

id: ProcedureId
namespace: NamespaceId
params: Vec<ProcedureParam>
return_type: Option<TypeConstraint>
trigger: RqlTriggerTest
User-defined RQL test procedure. Persisted; only callable from test context.
Fields

id: ProcedureId
namespace: NamespaceId
params: Vec<ProcedureParam>
return_type: Option<TypeConstraint>Native
Built-in Rust procedure registered into the runtime registry. Ephemeral.
Fields

id: ProcedureId
namespace: NamespaceId
params: Vec<ProcedureParam>
return_type: Option<TypeConstraint>Ffi
Procedure loaded from an FFI shared library at boot. Ephemeral.
Fields

id: ProcedureId
namespace: NamespaceId
params: Vec<ProcedureParam>
return_type: Option<TypeConstraint>Wasm
Procedure loaded from a WASM module at boot. Ephemeral.
Fields

id: ProcedureId
namespace: NamespaceId
params: Vec<ProcedureParam>
return_type: Option<TypeConstraint>
module_id: WasmModuleIdImplementations
Sourceimpl Procedure
impl Procedure
pub fn id(&self) -> ProcedureId
pub fn namespace(&self) -> NamespaceId
pub fn name(&self) -> &str
pub fn params(&self) -> &[ProcedureParam]
pub fn return_type(&self) -> Option<&TypeConstraint>
pub fn kind(&self) -> ProcedureKind
Sourcepub fn is_persistent(&self) -> bool
pub fn is_persistent(&self) -> bool
True for variants that live in MVCC storage (Rql, Test). False for Native/Ffi/Wasm which are repopulated from the runtime registry on every boot.
Sourcepub fn event_variant(&self) -> Option<VariantRef>
pub fn event_variant(&self) -> Option<VariantRef>
Event variant this procedure is bound to, if any. Only Rql procedures with RqlTrigger::Event return Some.
Sourcepub fn native_name(&self) -> Option<&str>
pub fn native_name(&self) -> Option<&str>
Native registry lookup name for Native/Ffi/Wasm variants. None for Rql/Test.