Structs
- Subscription
Column Def - A column definition for a subscription. Simpler than regular ColumnDef - only has id, name, and type.
- Subscription
Def
Constants
- IMPLICIT_
COLUMN_ OP - Implicit column names for subscriptions
Functions
- subscription_
flow_ name - Returns the flow name for a subscription using the deterministic naming convention. Subscription flows are always created in the system namespace.
- subscription_
flow_ namespace - Returns the namespace ID where subscription flows are created (system namespace).