pub struct LruCache<K, V> { /* private fields */ }Expand description
Thread-safe LRU cache using DashMap with approximate LRU eviction.
Uses an atomic counter for access ordering instead of timestamps, providing better performance while maintaining approximate LRU semantics.
Implementations
Sourceimpl<K: Hash + Eq + Clone, V: Clone> LruCache<K, V>
impl<K: Hash + Eq + Clone, V: Clone> LruCache<K, V>
pub fn new(capacity: usize) -> Self
Sourcepub fn get(&self, key: &K) -> Option<V>
pub fn get(&self, key: &K) -> Option<V>
Get a value and update LRU order. Returns cloned value.
Sourcepub fn put(&self, key: K, value: V) -> Option<V>
pub fn put(&self, key: K, value: V) -> Option<V>
Put a value into the cache. Returns old value if key existed.
Sourcepub fn contains_key(&self, key: &K) -> bool
pub fn contains_key(&self, key: &K) -> bool
Check if cache contains a key (read-only, doesn’t update LRU order).