pub enum ColumnData<S: Storage = Cow> {
Show 28 variants
Bool(BoolContainer<S>),
Float4(NumberContainer<f32, S>),
Float8(NumberContainer<f64, S>),
Int1(NumberContainer<i8, S>),
Int2(NumberContainer<i16, S>),
Int4(NumberContainer<i32, S>),
Int8(NumberContainer<i64, S>),
Int16(NumberContainer<i128, S>),
Uint1(NumberContainer<u8, S>),
Uint2(NumberContainer<u16, S>),
Uint4(NumberContainer<u32, S>),
Uint8(NumberContainer<u64, S>),
Uint16(NumberContainer<u128, S>),
Utf8 {
container: Utf8Container<S>,
max_bytes: MaxBytes,
},
Date(TemporalContainer<Date, S>),
DateTime(TemporalContainer<DateTime, S>),
Time(TemporalContainer<Time, S>),
Duration(TemporalContainer<Duration, S>),
IdentityId(IdentityIdContainer<S>),
Uuid4(UuidContainer<Uuid4, S>),
Uuid7(UuidContainer<Uuid7, S>),
Blob {
container: BlobContainer<S>,
max_bytes: MaxBytes,
},
Int {
container: NumberContainer<Int, S>,
max_bytes: MaxBytes,
},
Uint {
container: NumberContainer<Uint, S>,
max_bytes: MaxBytes,
},
Decimal {
container: NumberContainer<Decimal, S>,
precision: Precision,
scale: Scale,
},
Any(AnyContainer<S>),
DictionaryId(DictionaryContainer<S>),
Option {
inner: Box<ColumnData<S>>,
bitvec: S::BitVec,
},
}Variants
Bool(BoolContainer<S>)
Float4(NumberContainer<f32, S>)
Float8(NumberContainer<f64, S>)
Int1(NumberContainer<i8, S>)
Int2(NumberContainer<i16, S>)
Int4(NumberContainer<i32, S>)
Int8(NumberContainer<i64, S>)
Int16(NumberContainer<i128, S>)
Uint1(NumberContainer<u8, S>)
Uint2(NumberContainer<u16, S>)
Uint4(NumberContainer<u32, S>)
Uint8(NumberContainer<u64, S>)
Uint16(NumberContainer<u128, S>)
Utf8
Date(TemporalContainer<Date, S>)
DateTime(TemporalContainer<DateTime, S>)
Time(TemporalContainer<Time, S>)
Duration(TemporalContainer<Duration, S>)
IdentityId(IdentityIdContainer<S>)
Uuid4(UuidContainer<Uuid4, S>)
Uuid7(UuidContainer<Uuid7, S>)
Blob
Int
Uint
Decimal
Any(AnyContainer<S>)
DictionaryId(DictionaryContainer<S>)
Option
Implementations
Sourceimpl ColumnData
impl ColumnData
pub fn extend(&mut self, other: ColumnData) -> Result<()>
Sourceimpl ColumnData
impl ColumnData
pub fn bool(data: impl IntoIterator<Item = bool>) -> Self
pub fn bool_optional(data: impl IntoIterator<Item = Option<bool>>) -> Self
pub fn bool_with_capacity(capacity: usize) -> Self
pub fn bool_with_bitvec( data: impl IntoIterator<Item = bool>, bitvec: impl Into<BitVec>, ) -> Self
pub fn float4(data: impl IntoIterator<Item = f32>) -> Self
pub fn float4_optional(data: impl IntoIterator<Item = Option<f32>>) -> Self
pub fn float4_with_capacity(capacity: usize) -> Self
pub fn float4_with_bitvec( data: impl IntoIterator<Item = f32>, bitvec: impl Into<BitVec>, ) -> Self
pub fn float8(data: impl IntoIterator<Item = f64>) -> Self
pub fn float8_optional(data: impl IntoIterator<Item = Option<f64>>) -> Self
pub fn float8_with_capacity(capacity: usize) -> Self
pub fn float8_with_bitvec( data: impl IntoIterator<Item = f64>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int1(data: impl IntoIterator<Item = i8>) -> Self
pub fn int1_optional(data: impl IntoIterator<Item = Option<i8>>) -> Self
pub fn int1_with_capacity(capacity: usize) -> Self
pub fn int1_with_bitvec( data: impl IntoIterator<Item = i8>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int2(data: impl IntoIterator<Item = i16>) -> Self
pub fn int2_optional(data: impl IntoIterator<Item = Option<i16>>) -> Self
pub fn int2_with_capacity(capacity: usize) -> Self
pub fn int2_with_bitvec( data: impl IntoIterator<Item = i16>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int4(data: impl IntoIterator<Item = i32>) -> Self
pub fn int4_optional(data: impl IntoIterator<Item = Option<i32>>) -> Self
pub fn int4_with_capacity(capacity: usize) -> Self
pub fn int4_with_bitvec( data: impl IntoIterator<Item = i32>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int8(data: impl IntoIterator<Item = i64>) -> Self
pub fn int8_optional(data: impl IntoIterator<Item = Option<i64>>) -> Self
pub fn int8_with_capacity(capacity: usize) -> Self
pub fn int8_with_bitvec( data: impl IntoIterator<Item = i64>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int16(data: impl IntoIterator<Item = i128>) -> Self
pub fn int16_optional(data: impl IntoIterator<Item = Option<i128>>) -> Self
pub fn int16_with_capacity(capacity: usize) -> Self
pub fn int16_with_bitvec( data: impl IntoIterator<Item = i128>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint1(data: impl IntoIterator<Item = u8>) -> Self
pub fn uint1_optional(data: impl IntoIterator<Item = Option<u8>>) -> Self
pub fn uint1_with_capacity(capacity: usize) -> Self
pub fn uint1_with_bitvec( data: impl IntoIterator<Item = u8>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint2(data: impl IntoIterator<Item = u16>) -> Self
pub fn uint2_optional(data: impl IntoIterator<Item = Option<u16>>) -> Self
pub fn uint2_with_capacity(capacity: usize) -> Self
pub fn uint2_with_bitvec( data: impl IntoIterator<Item = u16>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint4(data: impl IntoIterator<Item = u32>) -> Self
pub fn uint4_optional(data: impl IntoIterator<Item = Option<u32>>) -> Self
pub fn uint4_with_capacity(capacity: usize) -> Self
pub fn uint4_with_bitvec( data: impl IntoIterator<Item = u32>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint8(data: impl IntoIterator<Item = u64>) -> Self
pub fn uint8_optional(data: impl IntoIterator<Item = Option<u64>>) -> Self
pub fn uint8_with_capacity(capacity: usize) -> Self
pub fn uint8_with_bitvec( data: impl IntoIterator<Item = u64>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint16(data: impl IntoIterator<Item = u128>) -> Self
pub fn uint16_optional(data: impl IntoIterator<Item = Option<u128>>) -> Self
pub fn uint16_with_capacity(capacity: usize) -> Self
pub fn uint16_with_bitvec( data: impl IntoIterator<Item = u128>, bitvec: impl Into<BitVec>, ) -> Self
pub fn utf8(data: impl IntoIterator<Item = impl Into<String>>) -> Self
pub fn utf8_optional(data: impl IntoIterator<Item = Option<String>>) -> Self
pub fn utf8_with_capacity(capacity: usize) -> Self
pub fn utf8_with_bitvec( data: impl IntoIterator<Item = impl Into<String>>, bitvec: impl Into<BitVec>, ) -> Self
pub fn date(data: impl IntoIterator<Item = Date>) -> Self
pub fn date_optional(data: impl IntoIterator<Item = Option<Date>>) -> Self
pub fn date_with_capacity(capacity: usize) -> Self
pub fn date_with_bitvec( data: impl IntoIterator<Item = Date>, bitvec: impl Into<BitVec>, ) -> Self
pub fn datetime(data: impl IntoIterator<Item = DateTime>) -> Self
pub fn datetime_optional( data: impl IntoIterator<Item = Option<DateTime>>, ) -> Self
pub fn datetime_with_capacity(capacity: usize) -> Self
pub fn datetime_with_bitvec( data: impl IntoIterator<Item = DateTime>, bitvec: impl Into<BitVec>, ) -> Self
pub fn time(data: impl IntoIterator<Item = Time>) -> Self
pub fn time_optional(data: impl IntoIterator<Item = Option<Time>>) -> Self
pub fn time_with_capacity(capacity: usize) -> Self
pub fn time_with_bitvec( data: impl IntoIterator<Item = Time>, bitvec: impl Into<BitVec>, ) -> Self
pub fn duration(data: impl IntoIterator<Item = Duration>) -> Self
pub fn duration_optional( data: impl IntoIterator<Item = Option<Duration>>, ) -> Self
pub fn duration_with_capacity(capacity: usize) -> Self
pub fn duration_with_bitvec( data: impl IntoIterator<Item = Duration>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uuid4(data: impl IntoIterator<Item = Uuid4>) -> Self
pub fn uuid4_optional(data: impl IntoIterator<Item = Option<Uuid4>>) -> Self
pub fn uuid4_with_capacity(capacity: usize) -> Self
pub fn uuid4_with_bitvec( data: impl IntoIterator<Item = Uuid4>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uuid7(data: impl IntoIterator<Item = Uuid7>) -> Self
pub fn uuid7_optional(data: impl IntoIterator<Item = Option<Uuid7>>) -> Self
pub fn uuid7_with_capacity(capacity: usize) -> Self
pub fn uuid7_with_bitvec( data: impl IntoIterator<Item = Uuid7>, bitvec: impl Into<BitVec>, ) -> Self
pub fn blob(data: impl IntoIterator<Item = Blob>) -> Self
pub fn blob_optional(data: impl IntoIterator<Item = Option<Blob>>) -> Self
pub fn blob_with_capacity(capacity: usize) -> Self
pub fn blob_with_bitvec( data: impl IntoIterator<Item = Blob>, bitvec: impl Into<BitVec>, ) -> Self
pub fn identity_id(identity_ids: impl IntoIterator<Item = IdentityId>) -> Self
pub fn identity_id_optional( identity_ids: impl IntoIterator<Item = Option<IdentityId>>, ) -> Self
pub fn identity_id_with_capacity(capacity: usize) -> Self
pub fn identity_id_with_bitvec( identity_ids: impl IntoIterator<Item = IdentityId>, bitvec: impl Into<BitVec>, ) -> Self
pub fn int(data: impl IntoIterator<Item = Int>) -> Self
pub fn int_optional(data: impl IntoIterator<Item = Option<Int>>) -> Self
pub fn uint(data: impl IntoIterator<Item = Uint>) -> Self
pub fn uint_optional(data: impl IntoIterator<Item = Option<Uint>>) -> Self
pub fn int_with_capacity(capacity: usize) -> Self
pub fn uint_with_capacity(capacity: usize) -> Self
pub fn int_with_bitvec( data: impl IntoIterator<Item = Int>, bitvec: impl Into<BitVec>, ) -> Self
pub fn uint_with_bitvec( data: impl IntoIterator<Item = Uint>, bitvec: impl Into<BitVec>, ) -> Self
pub fn decimal(data: impl IntoIterator<Item = Decimal>) -> Self
pub fn decimal_optional(data: impl IntoIterator<Item = Option<Decimal>>) -> Self
pub fn decimal_with_capacity(capacity: usize) -> Self
pub fn decimal_with_bitvec( data: impl IntoIterator<Item = Decimal>, bitvec: impl Into<BitVec>, ) -> Self
pub fn any(data: impl IntoIterator<Item = Box<Value>>) -> Self
pub fn any_optional(data: impl IntoIterator<Item = Option<Box<Value>>>) -> Self
pub fn any_with_capacity(capacity: usize) -> Self
pub fn any_with_bitvec( data: impl IntoIterator<Item = Box<Value>>, bitvec: impl Into<BitVec>, ) -> Self
pub fn dictionary_id(data: impl IntoIterator<Item = DictionaryEntryId>) -> Self
pub fn dictionary_id_optional( data: impl IntoIterator<Item = Option<DictionaryEntryId>>, ) -> Self
pub fn dictionary_id_with_capacity(capacity: usize) -> Self
pub fn dictionary_id_with_bitvec( data: impl IntoIterator<Item = DictionaryEntryId>, bitvec: impl Into<BitVec>, ) -> Self
Sourcepub fn typed_none(ty: &Type) -> Self
pub fn typed_none(ty: &Type) -> Self
Create a single-element None of the given type (bitvec=false).
This preserves the column type so comparisons
see the correct inner type rather than Option<Boolean>.
Sourcepub fn none_typed(ty: Type, len: usize) -> Self
pub fn none_typed(ty: Type, len: usize) -> Self
Create typed column data with all none values (bitvec all false). Always returns an Option-wrapped column to avoid the *_with_bitvec optimization that strips the Option wrapper when the bitvec is all-ones (which is vacuously true for empty bitvecs).
Sourceimpl ColumnData
impl ColumnData
Sourceimpl ColumnData
impl ColumnData
pub fn take(&self, num: usize) -> ColumnData
Sourceimpl<S: Storage> ColumnData<S>
impl<S: Storage> ColumnData<S>
Sourcepub fn unwrap_option(&self) -> (&ColumnData<S>, Option<&S::BitVec>)
pub fn unwrap_option(&self) -> (&ColumnData<S>, Option<&S::BitVec>)
Unwrap Option to inner data + bitvec. Non-Option returns self + None.
Sourcepub fn into_unwrap_option(self) -> (ColumnData<S>, Option<S::BitVec>)
pub fn into_unwrap_option(self) -> (ColumnData<S>, Option<S::BitVec>)
Owned version: consume self and return inner data + optional bitvec.
pub fn get_type(&self) -> Type
pub fn is_defined(&self, idx: usize) -> bool
pub fn is_bool(&self) -> bool
pub fn is_float(&self) -> bool
pub fn is_utf8(&self) -> bool
pub fn is_number(&self) -> bool
pub fn is_text(&self) -> bool
pub fn is_temporal(&self) -> bool
pub fn is_uuid(&self) -> bool
Sourceimpl<S: Storage> ColumnData<S>
impl<S: Storage> ColumnData<S>
pub fn none_count(&self) -> usize
Sourceimpl<S: Storage> ColumnData<S>
impl<S: Storage> ColumnData<S>
Sourceimpl ColumnData
impl ColumnData
Sourceimpl ColumnData
impl ColumnData
Sourceimpl ColumnData
impl ColumnData
pub fn push_value(&mut self, value: Value)